To reference stsynphot in publications, please cite [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3247832.svg)](https://doi.org/10.5281/zenodo.3247832)

#### Other forms of citation

Lim, P. L., et al. 2016, stsynphot User's Guide (Baltimore, MD: STScI),
http://stsynphot.readthedocs.io/en/latest/
